==> hubzero-submit-distributor_1.0.0.orig.tar.gz: hubzero-submit-distributor-1.0.0/monitorJobS.py <==
#!/usr/bin/env python
#
# @package      hubzero-submit-distributor
# @file         monitorJobS.py
# @author       Steve Clark <clarks@purdue.edu>
# @copyright    Copyright 2004-2011 Purdue University. All rights reserved.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2004-2011 Purdue University
# All rights reserved.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of Purdue University.
#
# ----------------------------------------------------------------------
#  monitorJobS.py
#
#  script which notifies monitorJob.py of a new job submission
#
import sys

from RemoteJobMonitor import RemoteJobMonitor

JOBMONITORHOST = ""
JOBMONITORPORT = 5727

def monitorJobS():
   """new job Submission"""
   messageSite = sys.argv[1]
   remoteJobId = sys.argv[2]

   remoteJobMonitor = RemoteJobMonitor(JOBMONITORHOST,JOBMONITORPORT)

   remoteJobMonitor.postNewJobSubmission(messageSite,remoteJobId)


if __name__ == '__main__':
   monitorJobS()

==> hubzero-submit-distributor_2.0.7.orig.tar.gz: hubzero-submit-distributor-2.0.7/monitorJobS.py <==
#!/usr/bin/env python
#
# @package      hubzero-submit-distributor
# @file         monitorJobS.py
# @author       Steven Clark <clarks@purdue.edu>
# @copyright    Copyright (c) 2004-2012 HUBzero Foundation, LLC.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2004-2012 HUBzero Foundation, LLC.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of HUBzero Foundation, LLC.
#
# ----------------------------------------------------------------------
#  monitorJobS.py
#
#  script which notifies monitorJob.py of a new job submission
#
import sys

from hubzero.submit.RemoteJobMonitor import RemoteJobMonitor

JOBMONITORHOST = ""
JOBMONITORPORT = 5727

def monitorJobS():
   """new job Submission"""
   messageSite = sys.argv[1]
   remoteJobId = sys.argv[2]
   hubUserId   = sys.argv[3]
   localJobId  = sys.argv[4]
   destination = sys.argv[5]

   remoteJobMonitor = RemoteJobMonitor(JOBMONITORHOST,JOBMONITORPORT)

   remoteJobMonitor.postNewJobSubmission(messageSite,remoteJobId, \
                                         hubUserId,localJobId,destination)


if __name__ == '__main__':
   monitorJobS()
